@@ -57,7 +57,8 @@
 #include "KonsoleSettings.h"
 #include "WindowSystemInfo.h"
 #include "TerminalDisplay.h"
-#include "settings/FileLocationSettings.h"
+#include "settings/ConfigurationDialog.h"
+#include "settings/TemporaryFilesSettings.h"
 #include "settings/GeneralSettings.h"
 #include "settings/ProfileSettings.h"
 #include "settings/TabBarSettings.h"
@@ -114,8 +115,8 @@ MainWindow::MainWindow() :
             this, &Konsole::MainWindow::newFromProfile);
     connect(_viewManager, &Konsole::ViewManager::newViewRequest,
             this, &Konsole::MainWindow::newTab);
-    connect(_viewManager, &Konsole::ViewManager::viewDetached, this,
-            &Konsole::MainWindow::viewDetached);
+    connect(_viewManager, &Konsole::ViewManager::terminalsDetached, this,
+            &Konsole::MainWindow::terminalsDetached);
 
     setCentralWidget(_viewManager->widget());
 
@@ -134,7 +135,7 @@ MainWindow::MainWindow() :
     // emulator (as they are reserved for use by terminal applications)
     correctStandardShortcuts();
 
-    setProfileList(new ProfileList(false, this));
+    setProfileList(new ProfileList(true, this));
 
     // this must come at the end
     applyKonsoleSettings();
@@ -230,6 +231,10 @@ void MainWindow::disconnectController(SessionController *controller)
     if (controller->isValid()) {
         guiFactory()->removeClient(controller);
     }
+
+    if (_pluggedController == controller) {
+        _pluggedController = nullptr;
+    }
 }
 
 void MainWindow::activeViewChanged(SessionController *controller)
@@ -317,8 +322,7 @@ void MainWindow::setupActions()
     collection->setDefaultShortcut(_newTabMenuAction, Konsole::ACCEL + Qt::SHIFT + Qt::Key_T);
     collection->setShortcutsConfigurable(_newTabMenuAction, true);
     _newTabMenuAction->setAutoRepeat(false);
-    connect(_newTabMenuAction, &KActionMenu::triggered,
-            this, [this] { newTab(_viewManager->activeContainer());});
+    connect(_newTabMenuAction, &KActionMenu::triggered, this, &MainWindow::newTab);
     collection->addAction(QStringLiteral("new-tab"), _newTabMenuAction);
     collection->setShortcutsConfigurable(_newTabMenuAction, true);
 
@@ -391,11 +395,8 @@ void MainWindow::setProfileList(ProfileList *list)
 {
     profileListChanged(list->actions());
 
-    connect(list, &Konsole::ProfileList::profileSelected, this,
-            [this](const Profile::Ptr &profile) { newFromProfile(_viewManager->activeContainer(), profile);});
-
-    connect(list, &Konsole::ProfileList::actionsChanged, this,
-            &Konsole::MainWindow::profileListChanged);
+    connect(list, &Konsole::ProfileList::profileSelected, this, &MainWindow::newFromProfile);
+    connect(list, &Konsole::ProfileList::actionsChanged, this, &Konsole::MainWindow::profileListChanged);
 }
 
 void MainWindow::profileListChanged(const QList<QAction *> &sessionActions)
@@ -461,17 +462,17 @@ void MainWindow::openUrls(const QList<QUrl> &urls)
 
     for (const auto &url : urls) {
         if (url.isLocalFile()) {
-            createSession(_viewManager->activeContainer(), defaultProfile, url.path());
+            createSession(defaultProfile, url.path());
         } else if (url.scheme() == QLatin1String("ssh")) {
-            createSSHSession(_viewManager->activeContainer(), defaultProfile, url);
+            createSSHSession(defaultProfile, url);
         }
     }
 }
 
-void MainWindow::newTab(TabbedViewContainer *tabWidget)
+void MainWindow::newTab()
 {
     Profile::Ptr defaultProfile = ProfileManager::instance()->defaultProfile();
-    createSession(tabWidget, defaultProfile, activeSessionDir());
+    createSession(defaultProfile, activeSessionDir());
 }
 
 void MainWindow::cloneTab()
@@ -481,15 +482,15 @@ void MainWindow::cloneTab()
     Session *session = _pluggedController->session();
     Profile::Ptr profile = SessionManager::instance()->sessionProfile(session);
     if (profile) {
-        createSession(_viewManager->activeContainer(), profile, activeSessionDir());
+        createSession(profile, activeSessionDir());
     } else {
         // something must be wrong: every session should be associated with profile
         Q_ASSERT(false);
-        newTab(_viewManager->activeContainer());
+        newTab();
     }
 }
 
-Session *MainWindow::createSession(TabbedViewContainer *tabWidget, Profile::Ptr profile, const QString &directory)
+Session *MainWindow::createSession(Profile::Ptr profile, const QString &directory)
 {
     if (!profile) {
         profile = ProfileManager::instance()->defaultProfile();
@@ -507,12 +508,12 @@ Session *MainWindow::createSession(TabbedViewContainer *tabWidget, Profile::Ptr
     // doesn't suffer a change in terminal size right after the session
     // starts.  Some applications such as GNU Screen and Midnight Commander
     // don't like this happening
-    _viewManager->createView(tabWidget, session);
-
+    auto newView = _viewManager->createView(session);
+    _viewManager->activeContainer()->addView(newView);
     return session;
 }
 
-Session *MainWindow::createSSHSession(TabbedViewContainer *tabWidget, Profile::Ptr profile, const QUrl &url)
+Session *MainWindow::createSSHSession(Profile::Ptr profile, const QUrl &url)
 {
     if (!profile) {
         profile = ProfileManager::instance()->defaultProfile();
@@ -537,8 +538,8 @@ Session *MainWindow::createSSHSession(TabbedViewContainer *tabWidget, Profile::P
     // doesn't suffer a change in terminal size right after the session
     // starts.  some applications such as GNU Screen and Midnight Commander
     // don't like this happening
-    _viewManager->createView(tabWidget, session);
-
+    auto newView = _viewManager->createView(session);
+    _viewManager->activeContainer()->addView(newView);
     return session;
 }
 
@@ -618,11 +619,13 @@ bool MainWindow::queryClose()
                                                                     "Close Current &Tab"),
                                                               QStringLiteral("tab-close")),
                                                      KStandardGuiItem::cancel(),
+                                                     // don't ask again name is wrong but I can't update.
+                                                     // this is not about tabs anymore. it's about empty tabs *or* splits.
                                                      QStringLiteral("CloseAllTabs"));
     } else {
         result = KMessageBox::warningYesNoCancel(this,
                                                  i18nc("@info",
-                                                       "There are %1 open tabs in this window. "
+                                                       "There are %1 open terminals in this window. "
                                                        "Do you still want to quit?",
                                                        openTabs),
                                                  i18nc("@title", "Confirm Close"),
@@ -632,6 +635,8 @@ bool MainWindow::queryClose()
                                                                 "Close Current &Tab"),
                                                           QStringLiteral("tab-close")),
                                                  KStandardGuiItem::cancel(),
+                                                 // don't ask again name is wrong but I can't update.
+                                                 // this is not about tabs anymore. it's about empty tabs *or* splits.
                                                  QStringLiteral("CloseAllEmptyTabs"));
     }
 
@@ -711,9 +716,9 @@ void MainWindow::showShortcutsDialog()
     }
 }
 
-void MainWindow::newFromProfile(TabbedViewContainer *tabWidget, const Profile::Ptr &profile)
+void MainWindow::newFromProfile(const Profile::Ptr &profile)
 {
-    createSession(tabWidget, profile, activeSessionDir());
+    createSession(profile, activeSessionDir());
 }
 
 void MainWindow::showManageProfilesDialog()
@@ -723,39 +728,39 @@ void MainWindow::showManageProfilesDialog()
 
 void MainWindow::showSettingsDialog(const bool showProfilePage)
 {
-    if (KConfigDialog::showDialog(QStringLiteral("settings"))) {
+    static ConfigurationDialog *confDialog = nullptr;
+    if (confDialog) {
+        confDialog->show();
         return;
     }
 
-    KConfigDialog *settingsDialog = new KConfigDialog(this, QStringLiteral("settings"), KonsoleSettings::self());
-    settingsDialog->setFaceType(KPageDialog::Tabbed);
+    confDialog = new ConfigurationDialog(this, KonsoleSettings::self());
 
-    auto generalSettings = new GeneralSettings(settingsDialog);
-    settingsDialog->addPage(generalSettings,
-                            i18nc("@title Preferences page name", "General"),
-                            QStringLiteral("utilities-terminal"));
+    const QString generalPageName = i18nc("@title Preferences page name", "General");
+    auto *generalPage = new KPageWidgetItem(new GeneralSettings(confDialog), generalPageName);
+    generalPage->setIcon(QIcon::fromTheme(QStringLiteral("utilities-terminal")));
+    confDialog->addPage(generalPage, true);
 
-    auto profileSettings = new ProfileSettings(settingsDialog);
-    KPageWidgetItem *profilePage = settingsDialog->addPage(profileSettings,
-                                                           i18nc("@title Preferences page name",
-                                                                 "Profiles"),
-                                                           QStringLiteral("configure"));
+    const QString profilePageName = i18nc("@title Preferences page name", "Profiles");
+    auto profilePage = new KPageWidgetItem(new ProfileSettings(confDialog), profilePageName);
+    profilePage->setIcon(QIcon::fromTheme(QStringLiteral("configure")));
+    confDialog->addPage(profilePage, true);
 
-    auto tabBarSettings = new TabBarSettings(settingsDialog);
-    settingsDialog->addPage(tabBarSettings,
-                            i18nc("@title Preferences page name", "TabBar"),
-                            QStringLiteral("system-run"));
+    const QString tabBarPageName = i18nc("@title Preferences page name", "Tab Bar");
+    auto tabBarPage = new KPageWidgetItem(new TabBarSettings(confDialog), tabBarPageName);
+    tabBarPage->setIcon(QIcon::fromTheme(QStringLiteral("system-run")));
+    confDialog->addPage(tabBarPage, true);
 
-    auto fileLocationSettings = new FileLocationSettings(settingsDialog);
-    settingsDialog->addPage(fileLocationSettings,
-                            i18nc("@title Preferences page name", "File Location"),
-                            QStringLiteral("configure"));
+    const QString temporaryFilesPageName = i18nc("@title Preferences page name", "Temporary Files");
+    auto temporaryFilesPage = new KPageWidgetItem(new TemporaryFilesSettings(confDialog), temporaryFilesPageName);
+    temporaryFilesPage->setIcon(QIcon::fromTheme(QStringLiteral("inode-directory")));
+    confDialog->addPage(temporaryFilesPage, true);
 
     if (showProfilePage) {
-        settingsDialog->setCurrentPage(profilePage);
+        confDialog->setCurrentPage(profilePage);
     }
 
-    settingsDialog->show();
+    confDialog->show();
 }
 
 void MainWindow::applyKonsoleSettings()
@@ -768,7 +773,7 @@ void MainWindow::applyKonsoleSettings()
         removeMenuAccelerators();
     }
 
-    _viewManager->setNavigationBehavior(KonsoleSettings::newTabBehavior());
+    _viewManager->activeContainer()->setNavigationBehavior(KonsoleSettings::newTabBehavior());
     setAutoSaveSettings(QStringLiteral("MainWindow"), KonsoleSettings::saveGeometryOnExit());
     updateWindowCaption();
 }
@@ -863,20 +868,20 @@ void MainWindow::triggerAction(const QString &name) const
 
 bool MainWindow::eventFilter(QObject *obj, QEvent *event)
 {
-    if (obj == _pluggedController->view()) {
+    if (!_pluggedController.isNull() && obj == _pluggedController->view()) {
         switch(event->type()) {
-        case QEvent::MouseButtonPress:
-        case QEvent::MouseButtonDblClick:
+            case QEvent::MouseButtonPress:
+            case QEvent::MouseButtonDblClick:
             switch(static_cast<QMouseEvent*>(event)->button()) {
-            case Qt::ForwardButton:
-                triggerAction(QStringLiteral("next-view"));
-                break;
-            case Qt::BackButton:
-                triggerAction(QStringLiteral("previous-view"));
-                break;
-            default: ;
+                case Qt::ForwardButton:
+                    triggerAction(QStringLiteral("next-view"));
+                    break;
+                case Qt::BackButton:
+                    triggerAction(QStringLiteral("previous-view"));
+                    break;
+                default: ;
             }
-        default: ;
+            default: ;
         }
     }
 
