@@ -123,7 +123,7 @@ Session::Session(QObject* parent) :
     connect(_emulation, &Konsole::Emulation::stateSet, this, &Konsole::Session::activityStateSet);
     connect(_emulation, &Konsole::Emulation::zmodemDownloadDetected, this, &Konsole::Session::fireZModemDownloadDetected);
     connect(_emulation, &Konsole::Emulation::zmodemUploadDetected, this, &Konsole::Session::fireZModemUploadDetected);
-    connect(_emulation, &Konsole::Emulation::changeTabTextColorRequest, this, &Konsole::Session::changeTabTextColorRequest);
+    connect(_emulation, &Konsole::Emulation::changeTabTextColorRequest, this, &Konsole::Session::changeTabTextColor);
     connect(_emulation, &Konsole::Emulation::profileChangeCommandReceived, this, &Konsole::Session::profileChangeCommandReceived);
     connect(_emulation, &Konsole::Emulation::flowControlKeyPressed, this, &Konsole::Session::updateFlowControlState);
     connect(_emulation, &Konsole::Emulation::primaryScreenInUse, this, &Konsole::Session::onPrimaryScreenInUse);
@@ -178,7 +178,9 @@ void Session::openTeletype(int fd)
     connect(_emulation, &Konsole::Emulation::useUtf8Request, _shellProcess, &Konsole::Pty::setUtf8Mode);
 
     // get notified when the pty process is finished
-    connect(_shellProcess, static_cast<void(Pty::*)(int,QProcess::ExitStatus)>(&Konsole::Pty::finished), this, &Konsole::Session::done);
+    connect(_shellProcess,
+            QOverload<int,QProcess::ExitStatus>::of(&Konsole::Pty::finished),
+            this, &Konsole::Session::done);
 
     // emulator size
     // Use a direct connection to ensure that the window size is set before it runs
@@ -541,13 +543,6 @@ void Session::setSessionAttribute(int what, const QString& caption)
         }
     }
 
-    /* I don't believe this has ever worked in KDE 4.x
-    if (what == 31) {
-        QString cwd = caption;
-        cwd = cwd.replace(QRegExp("^~"), QDir::homePath());
-        emit openUrlRequest(cwd);
-    }*/
-
     /* The below use of 32 works but appears to non-standard.
        It is from a commit from 2004 c20973eca8776f9b4f15bee5fdcb5a3205aa69de
      */
@@ -662,6 +657,11 @@ void Session::updateFlowControlState(bool suspended)
     }
 }
 
+void Session::changeTabTextColor(int i)
+{
+    qCDebug(KonsoleDebug) << "Changing tab text color is not implemented "<<i;
+}
+
 void Session::onPrimaryScreenInUse(bool use)
 {
 
@@ -936,7 +936,8 @@ void Session::sendMouseEvent(int buttons, int column, int line, int eventType)
 void Session::done(int exitCode, QProcess::ExitStatus exitStatus)
 {
     // This slot should be triggered only one time
-    disconnect(_shellProcess, static_cast<void(Pty::*)(int,QProcess::ExitStatus)>(&Konsole::Pty::finished),
+    disconnect(_shellProcess,
+               QOverload<int,QProcess::ExitStatus>::of(&Konsole::Pty::finished),
                this, &Konsole::Session::done);
 
     if (!_autoClose) {
@@ -1062,8 +1063,7 @@ void Session::updateSessionProcessInfo()
     if ((_sessionProcessInfo == nullptr) ||
             (processId() != 0 && processId() != _sessionProcessInfo->pid(&ok))) {
         delete _sessionProcessInfo;
-        _sessionProcessInfo = ProcessInfo::newInstance(processId(),
-                    tabTitleFormat(Session::LocalTabTitle));
+        _sessionProcessInfo = ProcessInfo::newInstance(processId());
         _sessionProcessInfo->setUserHomeDir();
     }
     _sessionProcessInfo->update();
@@ -1076,8 +1076,7 @@ bool Session::updateForegroundProcessInfo()
     const int foregroundPid = _shellProcess->foregroundProcessGroup();
     if (foregroundPid != _foregroundPid) {
         delete _foregroundProcessInfo;
-        _foregroundProcessInfo = ProcessInfo::newInstance(foregroundPid,
-                    tabTitleFormat(Session::LocalTabTitle));
+        _foregroundProcessInfo = ProcessInfo::newInstance(foregroundPid);
         _foregroundPid = foregroundPid;
     }
 
@@ -1134,28 +1133,29 @@ QString Session::getDynamicTitle()
     title.replace(QLatin1String("%n"), process->name(&ok));
 
     QString dir = _reportedWorkingUrl.toLocalFile();
+    ok = true;
     if (dir.isEmpty()) {
         // update current directory from process
         updateWorkingDirectory();
-        dir = process->validCurrentDir();
+        dir = process->currentDir(&ok);
     }
-
-    if (title.contains(QLatin1String("%D"))) {
-        const QString homeDir = process->userHomeDir();
-        if (!homeDir.isEmpty()) {
-            QString tempDir = dir;
-            // Change User's Home Dir w/ ~ only at the beginning
-            if (tempDir.startsWith(homeDir)) {
-                tempDir.remove(0, homeDir.length());
-                tempDir.prepend(QLatin1Char('~'));
+    if(!ok) {
+        title.replace(QLatin1String("%d"), QStringLiteral("-"));
+        title.replace(QLatin1String("%D"), QStringLiteral("-"));
+    } else {
+        if (title.contains(QLatin1String("%D"))) {
+            const QString homeDir = process->userHomeDir();
+            if (!homeDir.isEmpty()) {
+                // Change User's Home Dir w/ ~ only at the beginning
+                if (dir.startsWith(homeDir)) {
+                    dir.remove(0, homeDir.length());
+                    dir.prepend(QLatin1Char('~'));
+                }
             }
-            title.replace(QLatin1String("%D"), tempDir);
-        } else {
-            // Example: 'sudo top'  We have to replace %D with something
-            title.replace(QLatin1String("%D"), QStringLiteral("-"));
+            title.replace(QLatin1String("%D"), dir);
         }
+        title.replace(QLatin1String("%d"), process->formatShortDir(dir));
     }
-    title.replace(QLatin1String("%d"), process->formatShortDir(dir));
 
     return title;
 }
@@ -1374,7 +1374,9 @@ void Session::startZModem(const QString& zmodem, const QString& dir, const QStri
 
     connect(_zmodemProc, &KProcess::readyReadStandardOutput, this, &Konsole::Session::zmodemReadAndSendBlock);
     connect(_zmodemProc, &KProcess::readyReadStandardError, this, &Konsole::Session::zmodemReadStatus);
-    connect(_zmodemProc, static_cast<void(KProcess::*)(int,QProcess::ExitStatus)>(&KProcess::finished), this, &Konsole::Session::zmodemFinished);
+    connect(_zmodemProc,
+            QOverload<int,QProcess::ExitStatus>::of(&KProcess::finished),
+            this, &Konsole::Session::zmodemFinished);
 
     _zmodemProc->start();
 
