@@ -903,8 +903,9 @@ void Vt102Emulation::processToken(int token, int p, int q)
 
     // Set Cursor Style (DECSCUSR), VT520, with the extra xterm sequences
     // the first one is a special case, 'ESC[ q', which mimics 'ESC[1 q'
+    // Using 0 to reset to default is matching VTE, but not any official standard.
     case token_csi_sp ('q'    ) : emit setCursorStyleRequest(Enum::BlockCursor,     true);  break;
-    case token_csi_psp('q',  0) : emit setCursorStyleRequest(Enum::BlockCursor,     true);  break;
+    case token_csi_psp('q',  0) : emit resetCursorStyleRequest();                           break;
     case token_csi_psp('q',  1) : emit setCursorStyleRequest(Enum::BlockCursor,     true);  break;
     case token_csi_psp('q',  2) : emit setCursorStyleRequest(Enum::BlockCursor,     false); break;
     case token_csi_psp('q',  3) : emit setCursorStyleRequest(Enum::UnderlineCursor, true);  break;
@@ -1496,24 +1497,6 @@ char Vt102Emulation::eraseChar() const
     }
 }
 
-#if 0
-// print contents of the scan buffer
-static void hexdump(int *s, int len)
-{
-    int i;
-    for (i = 0; i < len; i++) {
-        if (s[i] == '\\') {
-            printf("\\\\");
-        } else if ((s[i]) > 32 && s[i] < 127) {
-            printf("%c", s[i]);
-        } else {
-            printf("\\%04x(hex)", s[i]);
-        }
-    }
-}
-
-#endif
-
 // return contents of the scan buffer
 static QString hexdump2(int *s, int len)
 {
@@ -1540,11 +1523,6 @@ void Vt102Emulation::reportDecodingError()
         return;
     }
 
-//    printf("Undecodable sequence: ");
-//    hexdump(tokenBuffer, tokenBufferPos);
-//    printf("\n");
-
     QString outputError = QStringLiteral("Undecodable sequence: ");
     outputError.append(hexdump2(tokenBuffer, tokenBufferPos));
-    //qDebug() << outputError;
 }
