@@ -22,6 +22,8 @@
 #include "MainWindow.h"
 #include "config-konsole.h" //krazy:exclude=includes
 #include "KonsoleSettings.h"
+#include "ViewManager.h"
+#include "ViewContainer.h"
 
 // OS specific
 #include <qplatformdefs.h>
@@ -369,7 +371,18 @@ void fillAboutData(KAboutData &aboutData)
 void restoreSession(Application &app)
 {
     int n = 1;
+
     while (KMainWindow::canBeRestored(n)) {
-        app.newMainWindow()->restore(n++);
+        auto mainWindow = app.newMainWindow();
+        mainWindow->restore(n++);
+        mainWindow->viewManager()->toggleActionsBasedOnState();
+        mainWindow->show();
+
+        // TODO: HACK without the code below the sessions would be `uninitialized`
+        // and the tabs wouldn't display the correct information.
+        auto tabbedContainer = qobject_cast<Konsole::TabbedViewContainer*>(mainWindow->centralWidget());
+        for(int i = 0; i < tabbedContainer->count(); i++) {
+            tabbedContainer->setCurrentIndex(i);
+        }
     }
 }
